@@ -110,19 +110,7 @@ proc file_report {} {
         return -1
     }
     bind . <Destroy> ""
-    # GNATS unlocks the PR, so we don't have to.
-    # (unless we're doing local disk access with pr-edit).
-    # This is probably going to change in future GNATS releases and we'll
-    # have to then always unlock the PR.
-    # unlock_pr $Tkeditpr(prid)
-    if {$TkGnats(GNATS_ACCESS) == "local"} {
-        # Note that you can't include the category when calling unlock_pr if
-        # TkGnats(GNATS_ACCESS_METHOD) == socket, which it won't (can't) if
-        # TkGnats(GNATS_ACCESS) == local, so the following is safe.
-        # This is currently neccessary because gnatsd and npr-edit unlock a
-        # PR when updated but pr-edit does not.
-        unlock_pr $flds(>Category)/$Tkeditpr(prid)
-    }
+    unlock_pr $Tkeditpr(prid)
     exit
 }
 
@@ -330,9 +318,6 @@ proc real_file_report {} {
                 # GNATS is locked! Try again later.
             } elseif {[string first "lock file exists" $errs] >= 0} {
                 set errs "GNATS is presently locked.\nPlease try again in a moment."
-            } elseif {$TkGnats(GNATS_ACCESS) != "local"} {
-                # This is a get-around for a bug in gnatsd that unlocks a pr when the update fails
-                lock_pr $Tkeditpr(prid)
             }
             Msg "Error filing $frm(>Category)/$Tkeditpr(prid):\n" "$errs"
         }
@@ -343,13 +328,14 @@ proc real_file_report {} {
     return 0
 }
 
-proc escape_dots_gnatsd {txt} {
+proc TTDescape_dots_gnatsd {txt} {
     set txttmp [split $txt \n]
     set len    [llength $txttmp]
     for {set l 0} {$l < $len} {incr l} {
         set line [lindex $txttmp $l]
-        # This is what RFC821 uses for SMTP, but we can't use this since gnatsd \
-        # doesn't remove the extra dot.
+        # TTD: This is what RFC821 uses for SMTP, but we can't use this since gnatsd
+        # doesn't remove the extra dot and you'd get another dot every time the PR is edited.
+        # When gnatsd is fixed this proc goes away and we just need escape_dots.
         #if {[string match .* $line]}
         if {$line == "."} {
             #puts "escaping this line: $line"
@@ -372,8 +358,9 @@ proc write_multitextfld {fout flds tag} {
     if {$TkGnats(GNATS_ACCESS_METHOD) == "batch"} {
         puts $fout $txt
     } {
-        #change this to escape_dots if gnatsd is ever fixed (it doesn't remocve the extra dot)
-        puts $fout [escape_dots_gnatsd $txt]
+        # TTD change this to escape_dots if gnatsd is ever fixed
+        # (it doesn't remove the extra dot at its end)
+        puts $fout [escape_dots $txt]
     }
 }
 
@@ -745,6 +732,7 @@ proc edit_window {} {
         >Description
         >How-To-Repeat
         >Environment
+        >Organization
         >Audit-Trail
         >Unformatted
         >Fix
